==> chaosmesh-model-5.1.2-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/StressChaosSpecBuilder.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class StressChaosSpecBuilder extends StressChaosSpecFluentImpl<StressChaosSpecBuilder> implements VisitableBuilder<StressChaosSpec,StressChaosSpecBuilder> {

    StressChaosSpecFluent<?> fluent;
    Boolean validationEnabled;

    public StressChaosSpecBuilder() {
        this(true);
    }

    public StressChaosSpecBuilder(Boolean validationEnabled) {
        this(new StressChaosSpec(), validationEnabled);
    }

    public StressChaosSpecBuilder(StressChaosSpecFluent<?> fluent) {
        this(fluent, true);
    }

    public StressChaosSpecBuilder(StressChaosSpecFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new StressChaosSpec(), validationEnabled);
    }

    public StressChaosSpecBuilder(StressChaosSpecFluent<?> fluent,StressChaosSpec instance) {
        this(fluent, instance, true);
    }

    public StressChaosSpecBuilder(StressChaosSpecFluent<?> fluent,StressChaosSpec instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withContainerName(instance.getContainerName()); 
        fluent.withDuration(instance.getDuration()); 
        fluent.withMode(instance.getMode()); 
        fluent.withScheduler(instance.getScheduler()); 
        fluent.withSelector(instance.getSelector()); 
        fluent.withStressngStressors(instance.getStressngStressors()); 
        fluent.withStressors(instance.getStressors()); 
        fluent.withValue(instance.getValue()); 
        this.validationEnabled = validationEnabled; 
    }

    public StressChaosSpecBuilder(StressChaosSpec instance) {
        this(instance,true);
    }

    public StressChaosSpecBuilder(StressChaosSpec instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withContainerName(instance.getContainerName()); 
        this.withDuration(instance.getDuration()); 
        this.withMode(instance.getMode()); 
        this.withScheduler(instance.getScheduler()); 
        this.withSelector(instance.getSelector()); 
        this.withStressngStressors(instance.getStressngStressors()); 
        this.withStressors(instance.getStressors()); 
        this.withValue(instance.getValue()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.chaosmesh.v1alpha1.EditableStressChaosSpec build() {
        EditableStressChaosSpec buildable = new EditableStressChaosSpec(fluent.getContainerName(),fluent.getDuration(),fluent.getMode(),fluent.getScheduler(),fluent.getSelector(),fluent.getStressngStressors(),fluent.getStressors(),fluent.getValue());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        StressChaosSpecBuilder that = (StressChaosSpecBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> chaosmesh-model-5.3.2-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/StressChaosSpecBuilder.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class StressChaosSpecBuilder extends StressChaosSpecFluentImpl<StressChaosSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<StressChaosSpec,StressChaosSpecBuilder> {

    StressChaosSpecFluent<?> fluent;
    Boolean validationEnabled;

    public StressChaosSpecBuilder() {
        this(true);
    }

    public StressChaosSpecBuilder(Boolean validationEnabled) {
        this(new StressChaosSpec(), validationEnabled);
    }

    public StressChaosSpecBuilder(StressChaosSpecFluent<?> fluent) {
        this(fluent, true);
    }

    public StressChaosSpecBuilder(StressChaosSpecFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new StressChaosSpec(), validationEnabled);
    }

    public StressChaosSpecBuilder(StressChaosSpecFluent<?> fluent,StressChaosSpec instance) {
        this(fluent, instance, true);
    }

    public StressChaosSpecBuilder(StressChaosSpecFluent<?> fluent,StressChaosSpec instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withContainerName(instance.getContainerName()); 
        fluent.withDuration(instance.getDuration()); 
        fluent.withMode(instance.getMode()); 
        fluent.withScheduler(instance.getScheduler()); 
        fluent.withSelector(instance.getSelector()); 
        fluent.withStressngStressors(instance.getStressngStressors()); 
        fluent.withStressors(instance.getStressors()); 
        fluent.withValue(instance.getValue()); 
        this.validationEnabled = validationEnabled; 
    }

    public StressChaosSpecBuilder(StressChaosSpec instance) {
        this(instance,true);
    }

    public StressChaosSpecBuilder(StressChaosSpec instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withContainerName(instance.getContainerName()); 
        this.withDuration(instance.getDuration()); 
        this.withMode(instance.getMode()); 
        this.withScheduler(instance.getScheduler()); 
        this.withSelector(instance.getSelector()); 
        this.withStressngStressors(instance.getStressngStressors()); 
        this.withStressors(instance.getStressors()); 
        this.withValue(instance.getValue()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.chaosmesh.v1alpha1.EditableStressChaosSpec build() {
        EditableStressChaosSpec buildable = new EditableStressChaosSpec(fluent.getContainerName(),fluent.getDuration(),fluent.getMode(),fluent.getScheduler(),fluent.getSelector(),fluent.getStressngStressors(),fluent.getStressors(),fluent.getValue());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        StressChaosSpecBuilder that = (StressChaosSpecBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
